@@ -30,7 +30,7 @@ class Api(object):
             'auth-token': access_token,
             'Accept': '*/*',
             'Accept-Language': 'en-US',
-            'User-Agent': 'FordPass/5 CFNetwork/1333.0.4 Darwin/21.5.0',
+            'User-Agent': 'FordPass/24 CFNetwork/1399 Darwin/22.1.0',
             'Content-Type': 'application/json',
             'Accept-Encoding': 'gzip, deflate, br',
             'Application-Id': regions[region],
